# Etsy Shop Integration

[Etsy is the global marketplace](https://www.etsy.com) for unique and creative goods with millions of shops run by 
hobbiests, entrapenures, entrepreneurs, and others. This module was designed to allow shop owners to integrate their 
Etsy shop with their Drupal website.

This module has be rewritten from the ground up for Drupal 9 and 10 using v3 of the Etsy API. With this, some 
previous features have been removed due to the focus of this module being shifted to solely interact with the API as a 
service. Other modules are encouraged to require Etsy Shop Integration as a dependency to implement shop features that are needed.

Etsy Shop Integration provides a service wrapper to the Etsy API and is designed to integrate a single Etsy shop.
**This module provides no ecommerce capabilities to comply with the [Etsy API terms of service](https://www.etsy.com/legal/api/#use).**

For a full description of the module, visit the
[project page](https://www.drupal.org/project/etsy).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/search/etsy).

## Table of contents

- Prerequisites
- Requirements
- Installation
- Configuration
- Usage
- Service Description
- Known Issues
- Maintainers

## Prerequisites

You must register a new application with Etsy. To do this, go to the [Etsy developer portal](https://www.etsy.com/developers) 
and register a new application. Once you have created your application, you will be given your API keystring and secret.
You will need these values later when [configuring this module](#configuration).

## Requirements

This module requires the following modules:

- [Imagecache External](https://www.drupal.org/project/imagecache_external)
- [Oauth2 Client](https://www.drupal.org/project/oauth2_client)

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

### OAuth2 Client

You will need to add your API credentials that you created under the [API Key](#api-key) section above. To add your credentials,
navigate to _/admin/config/system/oauth2-client_. You will see an OAuth2 Client labeled "_etsy_". Under the Operations column,
click the arrow and select the _Edit_ link.

In the form, check the _Enabled_ checkbox. Then under the section labeled "_Client Settings: Etsy"_, enter your Etsy 
**keystring** into the _Client ID_ field and your Etsy **shared secret** into the _Client Secret_ field. Click the
button labeled _Save and request token_.

### Module settings

To configure the module, navigate to _/admin/config/services/etsy_. Enter your Etsy shop ID in the field provided.

#### Caching

Currently Etsy API has a rate limit of requests to 5,000 per 24-hour period. Because of this, sites are encouraged to set a cache value
in the configuration. [See the official documentation](https://developers.etsy.com/documentation/essentials/rate-limits)
for more information on rate limits and how they apply to your use-case.

## Usage

The Etsy API service is accessed like any other service as described in the [Drupal documentation](https://www.drupal.org/docs/drupal-apis/services-and-dependency-injection/services-and-dependency-injection-in-drupal-8#s-accessing-services)
using <em>dependency injection</em> or <em>static Drupal methods</em>.

## Service Description

Currently, this module supports the following API method calls:

- `EtsyService::ping()` - Pings the Etsy API and if properly connected, returns an object with the application ID for the supplied OAuth2 credentials.
- `EtsyService::getMe()` - Returns basic info for the user making the request.
- `EtsyService::getListingsByShop()` - Retrieves the listings for the configured store. Results can be optionally limited and filtered.
- `EtsyService::getListing()` - Retrieves a single listing.
- `EtsyService::getShop()` - Retrieves the information for the configured store. Specific shop properties can be returned rather than the entire shop object.
- `EtsyService::getShopSections()` - Retrieves the sections for the configured store.

See the [official Etsy API documentation](https://developers.etsy.com/documentation) for more information on the various API methods.

## Known Issues

No known issues. [Submit all issues to the project issue queue.](https://www.drupal.org/project/issues/etsy)

## Maintainers

Current maintainers:

- [r0nn1ef](https://www.drupal.org/r0nn1ef)